@@ -1227,16 +1227,28 @@ clearlooks_draw_menuitem (cairo_t *cr,
                           const WidgetParameters          *widget,
                           int x, int y, int width, int height)
 {
-	CairoColor *fill   = (CairoColor*)&colors->spot[1];
-	CairoColor *border = (CairoColor*)&colors->spot[1];
+	CairoColor *fill = (CairoColor*)&colors->spot[1];
+	CairoColor fill_shade;
+	CairoColor *border = (CairoColor*)&colors->spot[2];
+	cairo_pattern_t *pattern;
+	
+	shade (fill, &fill_shade, 0.85);
 	
 	cairo_translate      (cr, x, y);
 	cairo_set_line_width (cr, 1.0);
 	
-	cairo_rectangle      (cr, 0, 0, width, height);
+	clearlooks_rounded_rectangle (cr, 0, 0, width, height, 3.0, widget->corners);
 	
-	cairo_set_source_rgb (cr, fill->r, fill->g, fill->b);
-	cairo_fill           (cr);
+	pattern = cairo_pattern_create_linear (0, 0, 0, height);
+	cairo_pattern_add_color_stop_rgb (pattern, 0,   fill->r, fill->g, fill->b);
+	cairo_pattern_add_color_stop_rgb (pattern, 1.0, fill_shade.r, fill_shade.g, fill_shade.b);
+	
+	cairo_set_source (cr, pattern);
+	cairo_fill_preserve  (cr);
+	cairo_pattern_destroy (pattern);
+	
+	cairo_set_source_rgb (cr, border->r, border->g, border->b);
+	cairo_stroke	         (cr);
 }
 
 void
@@ -1650,3 +1662,34 @@ clearlooks_draw_arrow (cairo_t *cr,
 	_clearlooks_draw_arrow (cr, color, arrow->direction, arrow->type,
 	                        tx, ty, width, height);
 }
+
+void
+clearlooks_draw_resize_grip (cairo_t *cr,
+                             const ClearlooksColors          *colors,
+                             const WidgetParameters          *widget,
+                             const ResizeGripParameters      *grip,
+                             int x, int y, int width, int height)
+{
+ 	CairoColor *dark = (CairoColor*)&colors->shade[4];
+	int lx, ly;
+ 
+	cairo_set_line_width (cr, 1);
+
+	for (ly=0; ly<3; ly++) // vertically, three rows of dots
+	{
+		for (lx=0; lx<=ly; lx++) // horizontally
+		{
+			int ny = (2-ly) * 5;
+			int nx = lx * 4;
+
+			cairo_set_source_rgb (cr, dark->r, dark->g, dark->b);
+			cairo_arc (cr, x+width-nx-1, y+height-ny-1, 1.3, 0, M_PI*2);
+			cairo_fill (cr);
+
+			cairo_set_source_rgba (cr, 1, 1, 1, 0.5);
+			cairo_arc (cr, x+width-nx, y+height-ny, 1.3, 0, M_PI*2);
+			cairo_fill (cr);
+		}
+	}
+}
+
