@@ -22,7 +22,7 @@
  */
 #include <gtk/gtkstyle.h>
 
-#include "clearlooks_draw.h"
+#include "clearlooks_types.h"
 
 typedef struct _ClearlooksStyle ClearlooksStyle;
 typedef struct _ClearlooksStyleClass ClearlooksStyleClass;
@@ -36,68 +36,19 @@ extern GType clearlooks_type_style;
 #define CLEARLOOKS_IS_STYLE_CLASS(klass)   (G_TYPE_CHECK_CLASS_TYPE ((klass), CLEARLOOKS_TYPE_STYLE))
 #define CLEARLOOKS_STYLE_GET_CLASS(obj)    (G_TYPE_INSTANCE_GET_CLASS ((obj), CLEARLOOKS_TYPE_STYLE, ClearlooksStyleClass))
 
-typedef enum
-{
-	CL_BORDER_UPPER = 0,
-	CL_BORDER_LOWER,
-	CL_BORDER_UPPER_ACTIVE,
-	CL_BORDER_LOWER_ACTIVE,
-	CL_BORDER_COUNT
-} ClBorderColorType;
-
-typedef enum
-{
-	CL_SCROLLBUTTON_BEGIN = 0,
-	CL_SCROLLBUTTON_END,
-	CL_SCROLLBUTTON_OTHER
-} ClScrollButtonType;
-
 struct _ClearlooksStyle
 {
 	GtkStyle parent_instance;
-	
-	GdkColor shade[9];
-	
-	GdkColor spot_color;
-	GdkColor spot1;
-	GdkColor spot2;
-	GdkColor spot3;
-	
-	GdkColor border[CL_BORDER_COUNT];
-	
-	/* from light to dark */
-	GdkGC *shade_gc[9];
-	GdkGC *border_gc[CL_BORDER_COUNT];
-	
-	GdkGC *spot1_gc;
-	GdkGC *spot2_gc;
-	GdkGC *spot3_gc;
-	
-	GdkColor inset_light[5];
-	GdkColor inset_dark[5];
-	
-	GdkColor button_g1[5];
-	GdkColor button_g2[5];
-	GdkColor button_g3[5];
-	GdkColor button_g4[5];
-	
-	GdkColor listview_bg[5];
 
-	GdkPixmap *radio_pixmap_nonactive[5];
-	GdkPixmap *radio_pixmap_active[5];
-	GdkPixmap *radio_pixmap_inconsistent[5];
-	GdkBitmap *radio_pixmap_mask; /* All masks are the same */
+	ClearlooksColors colors;
 	
-	GdkPixmap *check_pixmap_nonactive[5];
-	GdkPixmap *check_pixmap_active[5];
-	GdkPixmap *check_pixmap_inconsistent[5];
-	
-	guint sunkenmenubar:1;
-
 	guint8   progressbarstyle;
 	guint8   menubarstyle;
 	guint8   menuitemstyle;
 	guint8   listviewitemstyle;
+	GdkColor scrollbar_color;
+	gboolean has_scrollbar_color;
+	gboolean animation;
 };
 
 struct _ClearlooksStyleClass
@@ -105,4 +56,5 @@ struct _ClearlooksStyleClass
   GtkStyleClass parent_class;
 };
 
+
 void clearlooks_style_register_type (GTypeModule *module);
