@@ -4,6 +4,8 @@
 #include "crux-common.h"
 #include "crux-pixmaps.h"
 
+#include "cairo-support.h"
+
 #include <stdio.h>
 #include <math.h>
 #include <string.h>
@@ -166,10 +168,10 @@ draw_focus (GtkStyle *style,
 	    GtkStateType state_type,
 	    GdkRectangle *area,
 	    GtkWidget *widget,
-	    const gchar *detail, 
-	    gint x, 
-	    gint y, 
-	    gint width, 
+	    const gchar *detail,
+	    gint x,
+	    gint y,
+	    gint width,
 	    gint height);
 
 static void
@@ -250,7 +252,7 @@ crux_paint_menuitem_gradient (cairo_t * cr, GdkColor * c, gdouble x, gdouble y,
 }
 
 static void
-crux_paint_gradient (cairo_t * cr, GdkColor * c, GdkRectangle * rect, eazel_engine_gradient *gradient)
+crux_paint_gradient (cairo_t * cr, GdkColor * c, GdkRectangle * rect, eazel_engine_gradient_direction gradient)
 {
 	gint x, y, width, height;
 	x = rect->x; y = rect->y; width = rect->width; height = rect->height;
@@ -261,10 +263,16 @@ crux_paint_gradient (cairo_t * cr, GdkColor * c, GdkRectangle * rect, eazel_engi
 	r = c->red / 65536.0;
 	g = c->green / 65536.0;
 	b = c->blue / 65536.0;
-	if (gradient->direction == GRADIENT_VERTICAL)
-		crp = cairo_pattern_create_linear (x, y, x, y + height);
-	else if (gradient->direction == GRADIENT_HORIZONTAL)
-		crp = cairo_pattern_create_linear (x, y, x + width, y);
+	switch (gradient)
+	{
+		case GRADIENT_VERTICAL:
+			crp = cairo_pattern_create_linear (x, y, x, y + height);
+			break;
+		case GRADIENT_HORIZONTAL:
+			crp = cairo_pattern_create_linear (x, y, x + width, y);
+			break;
+		default: return;
+	}
 
 	cairo_pattern_add_color_stop_rgb (crp, 0.0, r*1.1, g*1.1, b*1.1);
 	cairo_pattern_add_color_stop_rgb (crp, 1.0, r*.8, g*.8, b*.8);
@@ -386,7 +394,7 @@ paint_stock_image (eazel_theme_data *theme_data,
 	{
 	    gdk_draw_pixmap (window, style->fg_gc[state_type], pixmap,
 			     xsrc, ysrc, x, y, width, height);
-	} 
+	}
 
 	if (mask != 0)
 	{
@@ -394,7 +402,7 @@ paint_stock_image (eazel_theme_data *theme_data,
 	    gdk_gc_set_clip_origin (style->fg_gc[state_type], 0, 0);
 	}
    }
-    
+
     eazel_engine_stock_free_pixmaps (theme_data->stock, type, pixmap, mask);
 }
 
@@ -432,7 +440,7 @@ paint_shadow (GdkWindow *window, GdkGC *a, GdkGC *b, GdkGC *c, GdkGC *d,
 	/* a: left/top, outer; b: left/top inner; c: right/bottom inner, d: right/bottom outer */
 
 	GdkGCValues values;
-	gdouble radius = (rounded) ? 2.0 : 0.1;
+	gdouble radius = (rounded) ? 2.0 : 0.01;
 	cairo_t * cr;
 
 	x += 0.5; y += 0.5;
@@ -608,7 +616,7 @@ paint_default (eazel_theme_data *theme_data,
 	int y_i = y + i;
 	int w_i = width - (i * 2);
 	int h_i = height - (i * 2);
-	
+
 	int d_corner = (corner && i == 0) ? corner : 0;
 
 	gdk_draw_line (window, gc, x_i + d_corner, y_i,
@@ -712,7 +720,7 @@ paint_arrow (GdkWindow *window, GdkGC *gc, GtkArrowType arrow_type,
 
     center_x = x + half_width;
     center_y = y + half_height;
-  
+
     switch (arrow_type)
     {
 	int i;
@@ -766,46 +774,6 @@ paint_arrow (GdkWindow *window, GdkGC *gc, GtkArrowType arrow_type,
     }
 }
 
-static void
-paint_tick (GdkWindow *window, GdkGC *gc, int x, int y)
-{
-#define PIXEL(a,b) gdk_draw_point (window, gc, x + a, y + b)
-
-    PIXEL (4, -4);
-    PIXEL (3, -3); PIXEL (4, -3); PIXEL (5, -3);
-    PIXEL (-2, -2);
-    PIXEL (2, -2); PIXEL (3, -2); PIXEL (4, -2);
-    PIXEL (-3, -1); PIXEL (-2, -1); PIXEL (-1, -1);
-    PIXEL (1, -1); PIXEL (2, -1); PIXEL (3, -1);
-    PIXEL (-2, 0); PIXEL (-1, 0); PIXEL (0, 0); PIXEL (1, 0); PIXEL (2, 0);
-    PIXEL (-1, 1); PIXEL (0, 1); PIXEL (1, 1);
-    PIXEL (0, 2);
-
-#undef PIXEL
-}
-
-static void
-paint_bullet (GdkWindow *window, GdkGC *gc, int x, int y)
-{
-#define PIXEL(a, b) gdk_draw_point (window, gc, x + a, y + b)
-
-    PIXEL (0, 0); PIXEL (0, -1); PIXEL (-1, 0); PIXEL (-1, -1);
-    PIXEL (1, -1); PIXEL (2, -1); PIXEL (-1, 1); PIXEL (-1, 2);
-
-    PIXEL (0, -2); PIXEL (1, -2);
-    PIXEL (-2, 0); PIXEL (-2, 1);
-    PIXEL (1, 0); PIXEL (2, 0); PIXEL (3, 0);
-    PIXEL (0, 1); PIXEL (1, 1); PIXEL (2, 1); PIXEL (3, 1);
-    PIXEL (0, 2); PIXEL (1, 2); PIXEL (2, 2);
-    PIXEL (0, 3); PIXEL (1, 3);
-
-    PIXEL (-1, -2); PIXEL (-2, -1); PIXEL (2, -2); PIXEL (3, -1);
-    PIXEL (-2, 2); PIXEL (-1, 3); PIXEL (2, 3); PIXEL (3, 2);
-
-#undef PIXEL
-}
-
-
 /* style functions */
 
 static void
@@ -1151,7 +1119,7 @@ draw_box (GtkStyle *style,
     if ((width == -1) && (height == -1))
     {
 	gdk_window_get_size (window, &width, &height);
-	
+
 	/* FIXME GNOME2
 	   if (gdk_window_get_type (window) != GDK_WINDOW_PIXMAP)
 	   set_bg = TRUE;
@@ -1242,29 +1210,69 @@ draw_box (GtkStyle *style,
 	{
 	    if (state_type != GTK_STATE_INSENSITIVE)
 	    {
-		gboolean focused;
-		focused = 1;
-		paint_stock_image (theme_data,
-				   focused ? EAZEL_ENGINE_PROGRESS_BAR
-				   : EAZEL_ENGINE_PROGRESS_BAR_INACTIVE,
-				   TRUE, FALSE, style, window, state_type,
-				   area, widget, x, y, width, height);
-		if (x > style->xthickness)
+		cairo_pattern_t *crp;
+		CairoColor c1,c2;
+		GtkProgressBarOrientation orientation;
+		cr = crux_begin_paint (window, area);
+
+		if (widget && GTK_IS_PROGRESS_BAR (widget))
+			orientation = gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget));
+		else
+			orientation = GTK_PROGRESS_LEFT_TO_RIGHT;
+
+		if (orientation == GTK_PROGRESS_LEFT_TO_RIGHT || orientation == GTK_PROGRESS_RIGHT_TO_LEFT)
+			crp = cairo_pattern_create_linear (x, y, x, y + height);
+		else
+			crp = cairo_pattern_create_linear (x, y, x + width, y);
+
+		/* draw end cap */
+		cairo_set_source_rgb (cr, 0, 0, 0);
+		if (orientation == GTK_PROGRESS_LEFT_TO_RIGHT)
 		{
-		    paint_stock_image (theme_data,
-				       EAZEL_ENGINE_PROGRESS_BAR_LEFT,
-				       TRUE, FALSE, style, window, state_type,
-				       area, widget, x - 2, y, -1, height);
+			cairo_move_to (cr, x + width + 0.5, y);
+			cairo_line_to (cr, x + width + 0.5, y + height);
 		}
-		if (widget != 0
-		    && x + width < widget->allocation.width - style->xthickness - 3)
+		else if (orientation == GTK_PROGRESS_RIGHT_TO_LEFT)
 		{
-		    paint_stock_image (theme_data,
-				       EAZEL_ENGINE_PROGRESS_BAR_RIGHT,
-				       TRUE, FALSE, style, window,
-				       state_type, area, widget,
-				       x + width, y, -1, height);
+			cairo_move_to (cr, x - 0.5, y);
+			cairo_line_to (cr, x - 0.5, y + height);
 		}
+		else if (orientation == GTK_PROGRESS_BOTTOM_TO_TOP)
+		{
+			cairo_move_to (cr, x, y - 0.5);
+			cairo_line_to (cr, x + width, y - 0.5);
+		}
+		else if (orientation == GTK_PROGRESS_TOP_TO_BOTTOM)
+		{
+			cairo_move_to (cr, x, y + height + 0.5);
+			cairo_line_to (cr, x + width, y + height + 0.5);
+		}
+		cairo_stroke (cr);
+
+		/* TODO: add shadow */
+
+		/* draw gradient */
+		cairo_rectangle (cr, x, y, width, height);
+		ge_gdk_color_to_cairo (&style->base[GTK_STATE_SELECTED], &c1);
+		ge_shade_color (&c1, &c2, 0.5);
+		cairo_pattern_add_color_stop_rgb (crp, 0.1, c1.r, c1.g, c1.b);
+		cairo_pattern_add_color_stop_rgb (crp, 1.0, c2.r, c2.g, c2.b);
+		cairo_set_source (cr, crp);
+		cairo_fill (cr);
+
+		/* draw bevel */
+		cairo_move_to (cr, x, y + height);
+		cairo_line_to (cr, x, y);
+		cairo_line_to (cr, x + width, y);
+		cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 0.4);
+		cairo_stroke (cr);
+		cairo_line_to (cr, x + width, y + height);
+		cairo_line_to (cr, x, y + height);
+		cairo_set_source_rgba (cr, 0.0, 0.0, 0.0, 0.4);
+		cairo_stroke (cr);
+
+		cairo_destroy (cr);
+		cairo_pattern_destroy (crp);
 	    }
 	    else
 	    {
@@ -1285,7 +1293,7 @@ draw_box (GtkStyle *style,
 	    y1 = /*style->ythickness +*/ y;
 	    y2 = (y + height) /*- style->ythickness*/;
 
-	    gdk_draw_line (window, style->dark_gc[state_type], 
+	    gdk_draw_line (window, style->dark_gc[state_type],
 			   x + x_offset, y1, x + x_offset, y2);
 	    gdk_draw_line (window, style->light_gc[state_type],
 			   x + 1 + x_offset, y1, x +1 + x_offset, y2);
@@ -1338,7 +1346,7 @@ draw_box (GtkStyle *style,
 		cr = crux_begin_paint (window, area);
 		gdk_gc_get_values (style->bg_gc[state_type], &values);
 		gdk_colormap_query_color (gdk_gc_get_colormap (style->bg_gc[state_type]), values.foreground.pixel, &values.foreground);
-		crux_paint_gradient (cr, &values.foreground, &full, gradient);
+		crux_paint_gradient (cr, &values.foreground, &full, gradient->direction);
 		cairo_destroy (cr);
 	}
 	else
@@ -1376,7 +1384,7 @@ draw_box (GtkStyle *style,
 			y += theme_data->default_thickness -1;
 			width -= theme_data->default_thickness * 2 -1,
 			height -= theme_data->default_thickness * 2 -1;
-		}	
+		}
 		fun (theme_data, window, style->black_gc, TRUE, TRUE,
 		     theme_data->default_thickness,
 		     x - (theme_data->default_thickness),
@@ -1419,12 +1427,12 @@ draw_polygon (GtkStyle *style,
 #ifndef M_PI
 #define M_PI    3.14159265358979323846
 #endif /*
-        * M_PI 
+        * M_PI
         */
 #ifndef M_PI_4
 #define M_PI_4  0.78539816339744830962
 #endif /*
-        * M_PI_4 
+        * M_PI_4
         */
 
     static const gdouble pi_over_4 = M_PI_4;
@@ -1642,7 +1650,7 @@ draw_arrow (GtkStyle *style,
 	  {
 	  XXX A hack, assumes that up arrow is drawn before
 	  XXX down arrow. (Currently it is)
-	  
+
 	  draw_shadow (style, window, GTK_STATE_NORMAL, GTK_SHADOW_OUT,
 	  NULL, widget, "entry", x - 2, 0,
 	  width + 4, window_height);
@@ -1658,7 +1666,7 @@ draw_arrow (GtkStyle *style,
 	    for (i = 0; i < 4; i++)
 	    {
 		gdk_draw_line (window, style->fg_gc[state_type],
-			       tem_x - i, tem_y + i, 
+			       tem_x - i, tem_y + i,
 			       tem_x + i, tem_y + i);
 	    }
 	}
@@ -1906,103 +1914,6 @@ draw_flat_box (GtkStyle *style,
 }
 #endif
 
-static void
-paint_check (GtkStyle *style,
-	     GdkWindow *window,
-	     GtkStateType state_type,
-	     GtkShadowType shadow_type,
-	     GdkRectangle *area,
-	     GtkWidget *widget,
-	     const gchar *detail, gint x, gint y, gint width, gint height,
-	     eazel_engine_stock_image stock_base)
-{
-    eazel_engine_stock_image type;
-    gboolean active = (shadow_type != GTK_SHADOW_OUT);
-    gboolean has_focus = (widget != 0 && GTK_WIDGET_HAS_FOCUS (widget));
-    gboolean menu_item = (widget != 0 && gtk_widget_get_ancestor (widget, GTK_TYPE_MENU_ITEM));
-
-    eazel_theme_data *theme_data;
-
-    theme_data = CRUX_RC_STYLE (style->rc_style)->theme_data;
-    g_assert (theme_data != NULL);
-
-    if (GTK_IS_TREE_VIEW (widget)) {
-      has_focus = FALSE;
-    }
-
-    if (DETAIL ("checkbutton") || DETAIL ("radiobutton"))
-    {
-	/* correct for braindeath in gtk_real_check_button_draw_indicator */
-	if (widget != 0 && GTK_IS_TOGGLE_BUTTON (widget))
-	    active = GTK_TOGGLE_BUTTON (widget)->active;
-	if (widget != 0)
-	{
-	    state_type = GTK_WIDGET_STATE (widget);
-	    /* XXX the widget gives us no way to tell between
-	       XXX checked, and checked-and-clicked states.. */
-	    if (active && state_type == GTK_STATE_ACTIVE)
-		state_type = GTK_STATE_NORMAL;
-	    else if (!has_focus && !active && state_type == GTK_STATE_ACTIVE)
-		state_type = GTK_STATE_NORMAL;
-	}
-    }
-
-    if (!menu_item)
-    {
-	switch (state_type)
-	{
-	case GTK_STATE_INSENSITIVE:
-	    type = (!active ? EAZEL_ENGINE_CHECK_DISABLED
-		    : EAZEL_ENGINE_CHECK_ACTIVE_DISABLED);
-	    break;
-
-	case GTK_STATE_PRELIGHT:
-	    type = (active
-		    ? (has_focus ? EAZEL_ENGINE_CHECK_ACTIVE_HI_FOCUS
-		       : EAZEL_ENGINE_CHECK_ACTIVE_HI)
-		    : (has_focus ? EAZEL_ENGINE_CHECK_HI_FOCUS
-		       : EAZEL_ENGINE_CHECK_HI));
-	    break;
-
-	case GTK_STATE_ACTIVE:
-	    type = (active
-		    ? (has_focus ? EAZEL_ENGINE_CHECK_ACTIVE_PRESSED_FOCUS
-		       : EAZEL_ENGINE_CHECK_ACTIVE)
-		    : (has_focus ? EAZEL_ENGINE_CHECK_PRESSED_FOCUS
-		       : EAZEL_ENGINE_CHECK_PRESSED));
-	    break;
-
-	default:
-	    type = (active
-		    ? (has_focus ? EAZEL_ENGINE_CHECK_ACTIVE_FOCUS
-		       : EAZEL_ENGINE_CHECK_ACTIVE)
-		    : (has_focus ? EAZEL_ENGINE_CHECK_FOCUS
-		       : EAZEL_ENGINE_CHECK));
-	}
-
-	paint_stock_image (theme_data, type + stock_base,
-			   FALSE, FALSE, style, window,
-			   state_type, area, widget,
-			   x-3, y-3, width+6, height+6);
-    }
-    else
-    {
-	if (!active)
-	    return;
-
-	if (stock_base == EAZEL_ENGINE_CHECK)
-	{
-	    paint_tick (window, style->fg_gc[state_type],
-			x + width / 2, y + width / 2);
-	}
-	else
-	{
-	    paint_bullet (window, style->fg_gc[state_type],
-			  x + width / 2, y + width / 2);
-	}
-    }
-}
-
 static void
 draw_check (GtkStyle *style,
 	    GdkWindow *window,
@@ -2012,8 +1923,62 @@ draw_check (GtkStyle *style,
 	    GtkWidget *widget,
 	    const gchar *detail, gint x, gint y, gint width, gint height)
 {
-    paint_check (style, window, state_type, shadow_type, area,
-		 widget, detail, x, y, width, height, EAZEL_ENGINE_CHECK);
+	cairo_t * cr;
+	gdouble cx, cy; /* co-ordinates for cairo */
+	GdkGCValues values;
+	GdkRectangle box;
+	GdkGC *a, *b, *c, *d;
+
+	gdk_gc_get_values (style->bg_gc[state_type], &values);
+	gdk_colormap_query_color (gdk_gc_get_colormap (style->bg_gc[state_type]), values.foreground.pixel, &values.foreground);
+
+	a = style->fg_gc[state_type];
+	d = style->fg_gc[state_type];
+	if (state_type == GTK_STATE_INSENSITIVE)
+	{
+		b = NULL;
+		c = NULL;
+	}
+	else
+	{
+		b = style->light_gc[state_type];
+		c = style->dark_gc[state_type];
+	}
+
+	paint_shadow (window, a, b, c, d, FALSE, x, y, height, height);
+
+	cr = crux_begin_paint (window, NULL);
+
+	if (state_type != GTK_STATE_INSENSITIVE)
+	{
+		box.x = x + 2;
+		box.y = y + 2;
+		box.height = box.width = height - 4;
+
+		crux_paint_gradient (cr, &values.foreground, &box, GRADIENT_VERTICAL);
+	}
+
+	if (shadow_type != GTK_SHADOW_OUT)
+	{
+		/* draw tick mark */
+		gdk_gc_get_values (a, &values);
+		gdk_colormap_query_color (gdk_gc_get_colormap (style->bg_gc[state_type]), values.foreground.pixel, &values.foreground);
+		gdk_cairo_set_source_color (cr, &values.foreground);
+		cairo_set_line_width (cr, 2.0);
+		cx = x + 0.5; width--;
+		cy = y + 0.5; height--;
+
+		/* TODO: draw drop shadow (if state is not insensitive) */
+
+		cairo_move_to (cr, x + 3.0, y + height * 0.5);
+		cairo_line_to (cr, x + width * 0.5, y + height * 0.7);
+		cairo_line_to (cr, x + width - 1.0, y + 3.0);
+		cairo_stroke (cr);
+		cairo_fill (cr);
+	}
+
+	cairo_destroy (cr);
+
 }
 
 static void
@@ -2025,8 +1990,58 @@ draw_option (GtkStyle *style,
 	     GtkWidget *widget,
 	     const gchar *detail, gint x, gint y, gint width, gint height)
 {
-    paint_check (style, window, state_type, shadow_type, area,
-		 widget, detail, x, y, width, height, EAZEL_ENGINE_OPTION);
+	cairo_t *cr;
+	cairo_pattern_t *crp;
+	GdkRectangle rect;
+	gdouble cx, cy, radius; /* cairo co-ordinates */
+	CairoColor c1, c2;
+
+
+	cx = x + (height / 2) + 0.5;
+	cy = y + (height / 2) + 0.5;
+	radius = (height / 2) - 1.0;
+
+	rect.x = x; rect.y = y;
+	rect.height = rect.width = height;
+
+	cr = crux_begin_paint (window, area);
+
+	cairo_set_line_width (cr, 1.0);
+	cairo_arc (cr, cx, cy, radius, 0.0, M_PI * 2);
+
+
+	if (state_type != GTK_STATE_INSENSITIVE)
+	{
+		ge_gdk_color_to_cairo (&style->white, &c1);
+		ge_shade_color (&c1, &c2, 0.2);
+
+		crp = cairo_pattern_create_linear (x + 0.5, y + 0.5, x + height - 1.0, y + height - 1.0);
+		if (shadow_type == GTK_SHADOW_OUT && state_type != GTK_STATE_ACTIVE)
+		{
+			cairo_pattern_add_color_stop_rgb (crp, 0.3, c1.r, c1.g, c1.b);
+			cairo_pattern_add_color_stop_rgb (crp, 1.2, c2.r, c2.g, c2.b);
+		}
+		else
+		{
+			cairo_pattern_add_color_stop_rgb (crp, 0.3, c2.r, c2.g, c2.b);
+			cairo_pattern_add_color_stop_rgb (crp, 1.2, c1.r, c1.g, c1.b);
+		}
+		cairo_set_source (cr, crp);
+		cairo_fill_preserve (cr);
+		cairo_pattern_destroy (crp);
+	}
+
+	gdk_cairo_set_source_color (cr, &style->fg[state_type]);
+	cairo_stroke (cr);
+
+	if (shadow_type == GTK_SHADOW_IN)
+	{
+		cairo_set_line_width (cr, 0.0);
+		cairo_arc (cr, cx, cy, radius - 2.5, 0.0, M_PI * 2);
+		cairo_fill (cr);
+	}
+
+	cairo_destroy (cr);
 }
 
 static void
@@ -2338,7 +2353,7 @@ draw_focus (GtkStyle *style,
 		return;
 	}
 	/* Make sure no widget is without a focus indicator! */
-	parent_style_class->draw_focus(style, window, state_type, area, widget, 
+	parent_style_class->draw_focus(style, window, state_type, area, widget,
 	                               detail, x, y, width, height);
 }
 
@@ -2355,7 +2370,7 @@ draw_slider (GtkStyle *style,
 {
     eazel_theme_data *theme_data;
     gboolean focused;
-    
+
     g_return_if_fail (style != NULL);
     g_return_if_fail (window != NULL);
 
@@ -2416,7 +2431,7 @@ draw_slider (GtkStyle *style,
 		/* XXX `4' is 1/2 height of thumb */
 		thumb_y = y + height / 2 - 4;
 	    }
-	    
+
 	    paint_stock_image (theme_data,
 			       width > height
 			       ? (state_type == GTK_STATE_PRELIGHT
